CREATE TABLE `course_target` (
    `id` BIGINT(20) NOT NULL COMMENT 'id',
    `school_id` BIGINT(20) NOT NULL COMMENT '学校id',
    `course_code` VARCHAR(20) NOT NULL COMMENT '课程编号',
    `course_name` VARCHAR(50) NULL COMMENT '课程名称',
    `target_name` VARCHAR(50) NULL COMMENT '课程目标',
    `target_content` MEDIUMTEXT NULL COMMENT '毕业要求指标',
    `degree_requirement` VARCHAR(255) NULL COMMENT '毕业要求',
    `total_weight` DECIMAL(6 , 2 ) NULL COMMENT '课程目标整体权重',
    `create_id` BIGINT(20) NULL COMMENT '创建人',
    `create_time` BIGINT(20) NULL COMMENT '创建时间',
    `update_id` BIGINT(20) NULL COMMENT '更新人',
    `update_time` BIGINT(20) NULL COMMENT '更新时间',
    PRIMARY KEY (`id`)
)  ENGINE=INNODB DEFAULT CHARACTER SET=UTF8MB4 COMMENT='课程目标表';

ALTER TABLE `course_target` 
ADD UNIQUE INDEX `course_target_unique` (`school_id` ASC, `course_code` ASC, `target_name` ASC) VISIBLE;
;

CREATE TABLE `course_evaluation` (
  `id` BIGINT(20) NOT NULL COMMENT 'id',
  `school_id` BIGINT(20) NOT NULL COMMENT '学校id',
  `course_code` VARCHAR(20) NOT NULL COMMENT '课程编号',
  `course_name` VARCHAR(50) NULL COMMENT '课程名称',
  `evaluation` VARCHAR(255) NOT NULL COMMENT '评价方式',
  `evaluation_desc` VARCHAR(255) NULL COMMENT '评价方式描述',
  `create_id` BIGINT(20) NULL COMMENT '创建人id',
  `create_time` BIGINT(20) NULL COMMENT '创建时间',
  `update_id` BIGINT(20) NULL COMMENT '更新人id',
  `update_time` BIGINT(20) NULL COMMENT '更新时间',
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8mb4
COMMENT = '课程评价方式';

ALTER TABLE `course_evaluation` 
ADD UNIQUE INDEX `course_evaluation_unique` (`school_id` ASC, `course_code` ASC, `evaluation` ASC) VISIBLE;
;

CREATE TABLE `course_weight` (
  `id` BIGINT(20) NOT NULL COMMENT 'id',
  `school_id` BIGINT(20) NOT NULL COMMENT '学校id',
  `course_code` VARCHAR(20) NOT NULL COMMENT '课程编号',
  `course_name` VARCHAR(50) NULL COMMENT '课程名称',
  `target_id` BIGINT(20) NOT NULL COMMENT '课程目标表id',
  `evaluation_id` BIGINT(20) NOT NULL COMMENT '课程评价表id',
  `enable` TINYINT(1) NOT NULL DEFAULT '1' COMMENT '使用状态 1:使用 0:未使用',
  `weight` DECIMAL(6,2) NULL COMMENT '权重',
  `target_score` DECIMAL(6,2) NULL COMMENT '目标分值',
  `create_id` BIGINT(20) NULL COMMENT '创建人',
  `create_time` BIGINT(20) NULL COMMENT '创建时间',
  `update_id` BIGINT(20) NULL COMMENT '更新人',
  `update_time` BIGINT(20) NULL COMMENT '更新时间',
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8mb4
COMMENT = '课程权重设置';

ALTER TABLE `course_weight` 
ADD UNIQUE INDEX `course_weight_unique` (`school_id` ASC, `course_code` ASC, `evaluation_id` ASC, `target_id` ASC) VISIBLE;
;


