package com.qmth.distributed.print.api;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.service.TCScoreNormalService;
import com.qmth.teachcloud.common.annotation.OperationLogDetail;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.enums.log.CustomizedOperationTypeEnum;
import com.qmth.teachcloud.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.io.IOException;

/**
 * <p>
 * 报告基本情况表 前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2024-02-18
 */
@Api(tags = "课程目标达成度-报告基本情况Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_COURSE_DEGREE)
public class TRBasicInfoController {

    @Resource
    TCScoreNormalService tcScoreNormalService;

    @ApiOperation(value = "报告管理列表")
    @RequestMapping(value = "/report/list", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.SEARCH)
    @ApiResponses({@ApiResponse(code = 200, message = "分页查询", response = Object.class)})
    public Object reportList(@ApiParam(value = "学期ID", required = true) @RequestParam Long semesterId,
                             @ApiParam(value = "考试ID", required = true) @RequestParam Long examId,
                             @ApiParam(value = "课程编码") @RequestParam(required = false) String courseCode,
                             @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                             @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(tcScoreNormalService.scoreList(new Page<>(pageNumber, pageSize), semesterId, examId, courseCode));
    }

    @ApiOperation(value = "查看报告")
    @RequestMapping(value = "/report/view", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.SEARCH)
    @ApiResponses({@ApiResponse(code = 200, message = "查看报告", response = Object.class)})
    public Object reportView(@ApiParam(value = "考试id", required = true) @RequestParam Long examId,
                             @ApiParam(value = "科目编码", required = true) @RequestParam String courseCode,
                             @ApiParam(value = "试卷编号", required = true) @RequestParam String paperNumber,
                             @ApiParam(value = "试卷类型", required = true) @RequestParam String paperType) {
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "保存报告")
    @RequestMapping(value = "/report/save", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.UPDATE)
    @ApiResponses({@ApiResponse(code = 200, message = "保存报告", response = Object.class)})
    public Object reportSave(@ApiParam(value = "保存报告结构", required = true) @RequestBody Object body) {
        return ResultUtil.ok(true);
    }


    @ApiOperation(value = "导出报告")
    @RequestMapping(value = "/report/export", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.EXPORT)
    @ApiResponses({@ApiResponse(code = 200, message = "下载成功", response = Object.class)})
    public void reportExport(@ApiParam(value = "考试id", required = true) @RequestParam Long examId,
                             @ApiParam(value = "科目编码", required = true) @RequestParam String courseCode,
                             @ApiParam(value = "试卷编号", required = true) @RequestParam String paperNumber,
                             @ApiParam(value = "试卷类型", required = true) @RequestParam String paperType) throws IOException {

    }
}
